<?php
/**
 * kreatif functions and definitions
 *
 * @package kreatif
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'kreatif_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function kreatif_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on kreatif, use a find and replace
	 * to change 'kreatif' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'kreatif', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'kreatif' ),
		'footer'  => __('Footer Menu', 'kreatif'),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link', 'audio'
	) );
	
	add_theme_support('custom-logo');

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'kreatif_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
	
	register_default_headers( array(
		'header' => array(
			'url'			=> '%s/images/header.jpg',
			'thumbnail_url'		=> '%s/images/header.jpg',
			'description'	=>	__('Header', 'kreatif')
		)
	));
	
	/**
	* Enable support for featured images.
	*/
	add_theme_support( 'post-thumbnails' ); 
	add_image_size('kreatif-home-thumb',800,600, true);
	add_image_size('kreatif-most-popular',400,300, true);
	add_image_size('kreatif-fc', 300, 500, true);

}
endif; // kreatif_setup
add_action( 'after_setup_theme', 'kreatif_setup' );


function kreatif_fonts_url() {
    $fonts_url = '';
    
    $hind = _x('on', 'Hind font: on or off', 'kreatif');
    
    $oswald = _x('on', 'Oswald font: on or off', 'kreatif');

	if ( 'off' !== $hind || 'off' !== $oswald) {
	    $font_families = array();
	
	    if ('off' !== $hind ) {
		    $font_families[] = 'Hind:400,700';
	    }
	    
	    if ('off' !== $oswald ) {
		    $font_families[] = 'Oswald:300,400,700';
	    }
	    
		$query_args = array(
		    'family' => urlencode( implode( '|', $font_families ) ),
		    'subset' => urlencode( 'latin,latin-ext' ),
		);
	}
	
	$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
 
    return $fonts_url;
}

function kreatif_scripts_styles() {
    wp_enqueue_style( 'kreatif-fonts', kreatif_fonts_url(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'kreatif_scripts_styles' );

/**
 * Enqueue the stylesheet.
 */
function kreatif_customizer_stylesheet() {

    wp_register_style( 'kreatif-customizer-css', get_template_directory_uri() . '/assets/css/customizer.css', NULL, NULL, 'all' );
    wp_enqueue_style( 'kreatif-customizer-css' );

}
add_action( 'customize_controls_print_styles', 'kreatif_customizer_stylesheet' );


function kreatif_set_post_views($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}
//To keep the count accurate, lets get rid of prefetching
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);


/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function kreatif_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Primary Sidebar', 'kreatif' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 1', 'kreatif' ),
		'id'            => 'sidebar-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 2', 'kreatif' ),
		'id'            => 'sidebar-3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 3', 'kreatif' ),
		'id'            => 'sidebar-4',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 4', 'kreatif' ),
		'id'            => 'sidebar-5',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'kreatif_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function kreatif_scripts() {
	wp_enqueue_style( 'kreatif-style', get_stylesheet_uri() );
	
	wp_enqueue_style('kreatif-bootstrap-style',get_template_directory_uri()."/assets/bootstrap/css/bootstrap.min.css", array('kreatif-style'));
	
	wp_enqueue_style('kreatif-main-skin',get_template_directory_uri()."/assets/css/main.css", array('kreatif-bootstrap-style'));
	
	wp_enqueue_style('kreatif-font-awesome',get_template_directory_uri()."/assets/font-awesome/css/font-awesome.min.css", array('kreatif-main-skin'));
	
	wp_enqueue_style('bx-slider-default-theme-skin', get_template_directory_uri(). "/assets/slider/jquery.bxslider.css", array('kreatif-font-awesome'));
	
	wp_enqueue_style('kreatif-nav', get_template_directory_uri(). "/assets/slicknav.css", array('bx-slider-default-theme-skin'));
	
	wp_enqueue_script('jquery');
	
	wp_enqueue_script( 'kreatif-slider-js', get_template_directory_uri() . '/js/jquery.bxslider.min.js', array(), true );
	
	if ( is_single() ) :
		wp_enqueue_script( 'kreatif-custom', get_template_directory_uri() . '/js/custom.js', array(), true );
	endif;
	
	wp_enqueue_script( 'kreatif-nav-js', get_template_directory_uri() . '/js/jquery.slicknav.js', array(), true );
	
	wp_enqueue_script('scroll-js', get_template_directory_uri()."/js/jquery-scrolltofixed-min.js", array('jquery'));

	wp_enqueue_script( 'kreatif-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'kreatif-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'kreatif_scripts' );

function kreatif_masonry() {
	wp_enqueue_script( 'kreatif-masonry-js', get_template_directory_uri() . '/js/salvattore.min.js', array(), true );
}

add_action('wp_footer', 'kreatif_masonry');

function kreatif_initialize_header() {

	echo "<script>"; ?>
	
		jQuery(document).ready(function(){
		  jQuery('.bxslider').bxSlider({
			  auto: true
		  });
		});	
		
		jQuery(document).ready(function(){
		  jQuery('.post-slider').bxSlider({
		    minSlides: 2,
		    maxSlides: 3,
		    slideWidth: 350,
		    slideMargin: 30,
		    moveSlides: 3,
		    infiniteLoop: false,
		    pager: false
		  });
		});
		
		jQuery(function(){
			jQuery('.menu').slicknav({
				prependTo: '#default-nav'
			});
		});
		
	<?php
	
	echo "</script>";
	
} 

add_action('wp_head', 'kreatif_initialize_header');

/**
 *	All the custom CSS codes get loaded from here.
**/
function kreatif_custom_css() {
	$desc	=	esc_attr( get_theme_mod('header_textcolor' ) );
	
	$css1	=	".site-description {
					color: #" . $desc . ";	
				}";
				
	$desc2	=	esc_html( get_theme_mod('kreatif-title-color') );
	
	$css2	=	".site-title a {
					color: " . $desc2 . ";	
				}";	
				
	wp_add_inline_style('kreatif-main-skin', $css1 . $css2 );
}

add_action('wp_enqueue_scripts','kreatif_custom_css');

function kreatif_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
?>
	<<?php echo $tag ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
	<?php if ( 'div' != $args['style'] ) : ?>
	<div id="div-comment-<?php comment_ID() ?>" class="comment-body">
	<?php endif; ?>
	<div class="comment-author vcard">
	<?php if ( $args['avatar_size'] != 0 ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
	<?php printf( __( '<cite class="fn">%s</cite>', 'kreatif' ), get_comment_author_link() ); ?>
	</div>
	<?php if ( $comment->comment_approved == '0' ) : ?>
		<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.','kreatif' ); ?></em>
		<br />
	<?php endif; ?>

	<div class="comment-meta commentmetadata"><a href="<?php echo esc_html( get_comment_link( $comment->comment_ID ) ); ?>">
		<?php
			/* translators: 1: date, 2: time */
			printf( __('%1$s','kreatif'), get_comment_date() ); ?></a><?php edit_comment_link( __( '(Edit)','kreatif' ), '  ', '' );
		?>
	</div>

	<div class="entry-content">
		<?php comment_text(); ?>
	</div>

	<div class="reply">
	<?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
	</div>
	<?php if ( 'div' != $args['style'] ) : ?>
	</div>
	<?php endif; ?>
<?php
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
